/*
This program is confidential and proprietary to MRJ Technology Solutions
and may not be reproduced, published or disclosed to others without
written authorization from MRJ.

Copyright (c) 1998 MRJ Technology Solutions, Inc. All Rights Reserved.

This program is derived from prior work some of which was originally
written as a joint project between the Numerical Aerospace Simulation
(NAS) Systems Division of NASA Ames Research Center and the National
Energy Research Supercomputer Center (NERSC) of Lawrence Livermore
National Laboratory.
*/

#include <pbs_config.h>   /* the master config generated by configure */

#include "Long.h"
#include "Long_.h"

#undef strToL
#undef strTouL
u_Long strTouL A_((const char *nptr, char **endptr, int base));

static const char ident[] = "@(#) $RCSfile: strToL.c,v $ $Revision: 2.0 $";

/*
 * strToL - returns the Long value representing the string whose first
 *	    character is *nptr, when interpreted as an integer in base, base.
 *
 * 	If base is zero, the base of the integer is determined by the way the
 * 	string starts.  The string is interpreted as decimal if the first
 * 	character after leading white space and an optional sign is a digit
 * 	between 1 and 9, inclusive.  The string is interpreted as octal if the
 * 	first character after leading white space and an optional sign is the
 * 	digit "0" and the next character is not an "X" (either upper or lower
 * 	case).  The string is interpreted as hexidecimal if the first character
 * 	after leading white space and an optional sign is the digit "0",
 * 	followed by an "X" (either upper or lower case).
 *
 * 	If base is greater than 1 and less than the number of characters in the
 *	Long_dig array, it represents the base in which the number will be
 *	interpreted.  Characters for digits beyond 9 are represented by the
 *	letters of the alphabet, either upper case or lower case.
 */

Long strToL(nptr, endptr, base)
    const char		*nptr;
    char		**endptr;
    int			base;
{
	Long		value;

	value = (Long)strTouL(nptr, endptr, base);
	if (Long_neg) {
		if (value >= 0) {
			value = lONG_MIN;
			errno = ERANGE;
		}
	} else if (value < 0) {
		value = lONG_MAX;
		errno = ERANGE;
	}
	return (value);
}
